

## Statistics with R--Second Edition
## Robert Stinerock

#       HOW TO CONDUCT MULTIPLE REGRESSION ANALYSIS - BAYES


#         SEE EXAMPLE 13.14 OF CHAPTER 13, SECTION 13.13

# MULTIPLE REGRESSION: (1) THE BAYES PROCEDURE; (2) EXTRACTING THE 
# PARAMETERS; (3) FINDING THE MAP, OR BAYESIAN VERSION OF THE MODE; (4) 
# FINDING THE HDI, OR CREDIBLE INTERVAL, AND (5) MAKING IMAGES OF 
# THE POSTERIOR DISTRIBUTIONS OF THE REGRESSION COEFFICIENTS.

#---------------------------------------------------------------------------------

options(scipen = 999)

library(rstanarm) # Must load the rstanarm package


#(1) Use the stan_glm() function to perform the regression (see Example 13.14)

model_bayes <- stan_glm(mpg ~ cyl + wt, data = mtcars, refresh = 0)




# (2) Use insight::get_parameters() function to review the result (Example 13.14)

posteriors <- insight::get_parameters(model_bayes)


head(posteriors); tail(posteriors) # Show first and last six lines of posteriors




# (3) To find the Bayesian version of the mode (the Maximum A Posteriori or MAP)
# use the map_estimate() function (Example 13.14)

library(bayestestR) # must load the bayestestR package

map_estimate(posteriors)




# (4) To find the 95% Highest Density Interval (or credible interval), use
# the hdi() function. (Example 13.14)


hdi(posteriors, ci = 0.95)



# (5) Make image of the posterior distribution of cyl (see Figure 13.14)

library(ggplot2)

ggplot(posteriors, aes(x = cyl)) +
  geom_density(fill = "blue") +
  geom_vline(xintercept = median(posteriors$cyl), color = "black")


# (6) Make image of the posterior distribution of wt (see Figure 13.14)

library(ggplot2)

ggplot(posteriors, aes(x = wt)) +
  geom_density(fill = "blue") +
  geom_vline(xintercept = median(posteriors$wt), color = "black")
