

# Statistics with R - 2nd Edition
# Robert Stinerock

#      HOW TO CONDUCT MULTIPLE REGRESSION ANALYSIS - OLS


#     SEE EXAMPLES 13.1, 13.2, 13.9, AND 13.10 OF CHAPTER 13 


# MULTIPLE REGRESSION: (1) THE OLS PROCEDURE; (2) EXTRACTING THE SUMMARY
# STATISTICS; (3) MAKING A CONFIDENCE INTERVAL ESTIMATE OF THE REGRESSION 
# COEFFICIENTS; (4) and (5) MAKING PREDICTIONS; AND (6) MAKING A PLOT OF 
# THE RESIDUALS.

#----------------------------------------------------------------------------

options(scipen = 999) # Suppress scientific notation

brisbane <- read.csv('brisbane.csv') # Import brisbane.csv.




#(1) Dependent variable is minutes; the independent variables are
# kilometers and visits; the model object is mr. (see Example 13.1)

mr <- lm(minutes ~ kilometers + visits, data = brisbane)




#(2) Use the summary(mr) extractor function to unpack the results
# of the analysis (see Example 13.1)

summary(mr)




#(3) Find the 95% confidence interval estimate of the regression
# coefficients (see Example 13.2)

confint(mr, level = 0.95)




# (4) Make predictions based on the values of the independent variables
# used in model calibration (Example 13.9)

fitted(mr)



# (5) Make predictions of values of the independent variables not used
# in the calibration. For example, find the predicted value of minutes
# for those driving assignments having the following values: 155 kilometers
# and 12 visits; and 110 kilometers and 14 visits (see Example 13.10)

newvalues <- data.frame(kilometers = c(155, 110), visits = c(12, 14))


predict(mr, newvalues)




# (6) Make a scatter plot of the residuals (see Figure 13.6)

plot(fitted(mr), resid(mr), abline(h = 0), pch = 19, 
     xlab = 'Predicted Value of y', ylab = 'Residuals')


