

## Statistics with R--Second Edition
## Robert Stinerock

#       HOW TO CONDUCT SIMPLE LINEAR REGRESSION ANALYSIS - BAYES


#         SEE EXAMPLE 12.14 OF CHAPTER 12, SECTION 12.10

# SIMPLE LINEAR REGRESSION: (1) THE BAYES PROCEDURE; (2) EXTRACTING THE 
# PARAMETERS; (3) FINDING THE MAP, OR BAYESIAN VERSION OF THE MODE; (4) 
# FINDING THE HDI, OR CREDIBLE INTERVAL, AND (5) MAKING AN IMAGE OF 
# THE POSTERIOR DISTRIBUTION OF THE REGRESSION COEFFICIENT.

#---------------------------------------------------------------------------------

options(scipen = 999)

library(rstanarm) # Must load the rstanarm package


#(1) Use the stan_glm() function to perform the regression (see Example 12.14)

model_bayes <- stan_glm(Sepal.Length ~ Petal.Length, data = iris, refresh = 0)




# (2) Use insight::get_parameters() function to review the result (Example 12.14)

posteriors <- insight::get_parameters(model_bayes)


head(posteriors); tail(posteriors) # Show first and last six lines of posteriors




# (3) To find the Bayesian version of the mode (the Maximum A Posteriori or MAP)
# use the map_estimate() function (see Interpretation (5), Example 12.14)

library(bayestestR) # must load the bayestestR package

map_estimate(posteriors$Petal.Length)




# (4) To find the 95% Highest Density Interval (or credible interval), use
# the hdi() function. (see Interpretation (5), Example 12.14)


hdi(posteriors$Petal.Length, ci = 0.95)

# an alternative way to find the credible interval is the quantile() function

quantile(posteriors$Petal.Length, c(0.025,0.975))




# (5) Make image of the posterior distribution (see Figure 12.12)

library(ggplot2)

ggplot(posteriors, aes(x = Petal.Length)) +
  geom_density(fill = "blue") +
  geom_vline(xintercept = median(posteriors$Petal.Length), color = "black")