
## Statistics with R--Second Edition
## Robert Stinerock


#         HOW TO CONDUCT SIMPLE LINEAR REGRESSION ANALYSIS - OLS


#   SEE EXAMPLES 12.8 - 12.12 OF CHAPTER 12, SECTIONS 12.4, 12.5, 12.9


# SIMPLE LINEAR REGRESSION: (1) THE OLS PROCEDURE; (2) EXTRACTING THE SUMMARY
# STATISTICS; (3) MAKING A CONFIDENCE INTERVAL ESTIMATE OF THE REGRESSION 
# COEFFICIENT; (4) and (5) MAKING PREDICTIONS; AND (6) MAKING A PLOT OF THE
# RESIDUALS.

#----------------------------------------------------------------------------

options(scipen = 999) # Suppress scientific notation

winnipeg_apt <- read.csv('winnipeg_apt.csv') # Import winnipeg_apt.csv.





# (1) Dependent variable is price; independent variable is sqft; 
# the model object is named slr (see Example 12.9)

slr <- lm(price ~ sqft, data = winnipeg_apt)




# (2) Use the summary(slr) extractor function to unpack the results of 
# the analysis (see Example 12.9)

summary(slr)




# (3) Find the 95% confidence interval estimate of the regression 
# coefficient (see Example 12.12)

confint(slr, level = 0.95)




# (4) Make predictions based on the values of independent variable used in  
# model calibration (see Example 12.10)

fitted(slr)




# (5) Make predictions of values of independent variable not used in 
# calibration.  For example, find predicted price for those apartments 
# having the following square feet of living space: 800, 900, 1000, 
# 1100, and 1200 (see Example 12.11)

price_new <- data.frame(sqft <- c(800, 900, 1000, 1100, 1200))

predict(slr, price_new)




# (6) Make a scatter plot of the residuals (see Figure 12.8 )

plot(winnipeg_apt$sqft, resid(slr), pch = 19, abline(h = 0), xlab =
  'Square Feet of Living Area', ylab = 'Residuals', main = 'Winnipeg
  Homes: Residuals Against the Independent Variables') 
